@@ -8,15 +8,15 @@ summary: >
 
 # [Denoising Diffusion Probabilistic Models (DDPM)](index.html) training
 
+[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/labmlai/annotated_deep_learning_paper_implementations/blob/master/labml_nn/diffusion/ddpm/experiment.ipynb)
+[![Open In Comet](https://images.labml.ai/images/comet.svg?experiment=capsule_networks&file=model)](https://www.comet.ml/labml/diffuse/view/FknjSiKWotr8fgZerpC1sV1cy/panels)
+
 This trains a DDPM based model on CelebA HQ dataset. You can find the download instruction in this
 [discussion on fast.ai](https://forums.fast.ai/t/download-celeba-hq-dataset/45873/3).
 Save the images inside [`data/celebA` folder](#dataset_path).
 
 The paper had used a exponential moving average of the model with a decay of $0.9999$. We have skipped this for
 simplicity.
-
-[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/labmlai/annotated_deep_learning_paper_implementations/blob/master/labml_nn/diffusion/ddpm/experiment.ipynb)
-[![Open In Comet](https://images.labml.ai/images/comet.svg?experiment=capsule_networks&file=model)](https://www.comet.ml/labml/diffuse/1260757bcd6148e084ad3a46c38ac5c4?experiment-tab=chart&showOutliers=true&smoothing=0&transformY=smoothing&xAxis=step)
 """
 from typing import List
 
@@ -41,7 +41,7 @@ class Configs(BaseConfigs):
     #  picks up an available CUDA device or defaults to CPU.
     device: torch.device = DeviceConfigs()
 
-    # U-Net model for $\textcolor{cyan}{\epsilon_\theta}(x_t, t)$
+    # U-Net model for $\textcolor{lightgreen}{\epsilon_\theta}(x_t, t)$
     eps_model: UNet
     # [DDPM algorithm](index.html)
     diffusion: DenoiseDiffusion
@@ -79,7 +79,7 @@ class Configs(BaseConfigs):
     optimizer: torch.optim.Adam
 
     def init(self):
-        # Create $\textcolor{cyan}{\epsilon_\theta}(x_t, t)$ model
+        # Create $\textcolor{lightgreen}{\epsilon_\theta}(x_t, t)$ model
         self.eps_model = UNet(
             image_channels=self.image_channels,
             n_channels=self.n_channels,
@@ -115,7 +115,7 @@ class Configs(BaseConfigs):
             for t_ in monit.iterate('Sample', self.n_steps):
                 # $t$
                 t = self.n_steps - t_ - 1
-                # Sample from $\textcolor{cyan}{p_\theta}(x_{t-1}|x_t)$
+                # Sample from $\textcolor{lightgreen}{p_\theta}(x_{t-1}|x_t)$
                 x = self.diffusion.p_sample(x, x.new_full((self.n_samples,), t, dtype=torch.long))
 
             # Log samples
