@@ -7,7 +7,7 @@ summary: A simple PyTorch implementation/tutorial of Wasserstein Generative Adve
 # Wasserstein GAN (WGAN)
 
 This is an implementation of
-[Wasserstein GAN](https://arxiv.org/abs/1701.07875).
+[Wasserstein GAN](https://papers.labml.ai/paper/1701.07875).
 
 The original GAN loss is based on Jensen-Shannon (JS) divergence
 between the real distribution $\mathbb{P}_r$ and generated distribution $\mathbb{P}_g$.
@@ -101,7 +101,7 @@ class DiscriminatorLoss(Module):
      \frac{1}{m} \sum_{i=1}^m f_w \big( g_\theta(z^{(i)}) \big)$$
     """
 
-    def __call__(self, f_real: torch.Tensor, f_fake: torch.Tensor):
+    def forward(self, f_real: torch.Tensor, f_fake: torch.Tensor):
         """
         * `f_real` is $f_w(x)$
         * `f_fake` is $f_w(g_\theta(z))$
@@ -127,7 +127,7 @@ class GeneratorLoss(Module):
 
     """
 
-    def __call__(self, f_fake: torch.Tensor):
+    def forward(self, f_fake: torch.Tensor):
         """
         * `f_fake` is $f_w(g_\theta(z))$
         """
