@@ -130,7 +130,7 @@ def _synthetic_experiment(is_adam: bool):
 
     We measure the performance of the optimizer as the regret,
     $$R(T) = \sum_{t=1}^T \big[ f_t(\theta_t) - f_t(\theta^*) \big]$$
-    where $theta_t$ is the parameters at time step $t$, and  $\theta^*$ is the
+    where $\theta_t$ is the parameters at time step $t$, and  $\theta^*$ is the
     optimal parameters that minimize $\mathbb{E}[f(\theta)]$.
 
     Now lets define the synthetic problem,
@@ -138,7 +138,7 @@ def _synthetic_experiment(is_adam: bool):
     \begin{align}
     f_t(x) =
     \begin{cases}
-    1010 x,  & \text{for $t \mod 101 = 1$} \\
+    1010 x,  & \text{for } t \mod 101 = 1 \\
     -10  x, & \text{otherwise}
     \end{cases}
     \end{align}
