@@ -8,6 +8,9 @@ summary: Implementation of DQN experiment with Atari Breakout
 
 This experiment trains a Deep Q Network (DQN) to play Atari Breakout game on OpenAI Gym.
 It runs the [game environments on multiple processes](../game.html) to sample efficiently.
+
+[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/labmlai/annotated_deep_learning_paper_implementations/blob/master/labml_nn/rl/dqn/experiment.ipynb)
+[![View Run](https://img.shields.io/badge/labml-experiment-brightgreen)](https://app.labml.ai/run/fe1ad986237511ec86e8b763a2d3f710)
 """
 
 import numpy as np
@@ -44,8 +47,6 @@ class Trainer:
                  update_target_model: int,
                  learning_rate: FloatDynamicHyperParam,
                  ):
-        # #### Configurations
-
         # number of workers
         self.n_workers = n_workers
         # steps sampled on each update
@@ -84,7 +85,7 @@ class Trainer:
 
         # Model for sampling and training
         self.model = Model().to(device)
-        # target model to get $\color{orange}Q(s';\color{orange}{\theta_i^{-}})$
+        # target model to get $\textcolor{orange}Q(s';\textcolor{orange}{\theta_i^{-}})$
         self.target_model = Model().to(device)
 
         # create workers
@@ -92,8 +93,12 @@ class Trainer:
 
         # initialize tensors for observations
         self.obs = np.zeros((self.n_workers, 4, 84, 84), dtype=np.uint8)
+
+        # reset the workers
         for worker in self.workers:
             worker.child.send(("reset", None))
+
+        # get the initial observations
         for i, worker in enumerate(self.workers):
             self.obs[i] = worker.child.recv()
 
@@ -170,9 +175,9 @@ class Trainer:
             # Get the Q-values of the next state for [Double Q-learning](index.html).
             # Gradients shouldn't propagate for these
             with torch.no_grad():
-                # Get $\color{cyan}Q(s';\color{cyan}{\theta_i})$
+                # Get $\textcolor{cyan}Q(s';\textcolor{cyan}{\theta_i})$
                 double_q_value = self.model(obs_to_torch(samples['next_obs']))
-                # Get $\color{orange}Q(s';\color{orange}{\theta_i^{-}})$
+                # Get $\textcolor{orange}Q(s';\textcolor{orange}{\theta_i^{-}})$
                 target_q_value = self.target_model(obs_to_torch(samples['next_obs']))
 
             # Compute Temporal Difference (TD) errors, $\delta$, and the loss, $\mathcal{L}(\theta)$.
@@ -266,7 +271,7 @@ def main():
         # Target model updating interval
         'update_target_model': 250,
         # Learning rate.
-        'learning_rate': FloatDynamicHyperParam(2.5e-4, (0, 1e-3)),
+        'learning_rate': FloatDynamicHyperParam(1e-4, (0, 1e-3)),
     }
 
     # Configurations
