@@ -28,7 +28,7 @@ $$x \Phi(x)$$ where $\Phi(x) = P(X \le x), X \sim \mathcal{N}(0,1)$
 ### Gated Linear Units
 
 This is a generic implementation that supports different variants including
-[Gated Linear Units](https://arxiv.org/abs/2002.05202) (GLU).
+[Gated Linear Units](https://papers.labml.ai/paper/2002.05202) (GLU).
 We have also implemented experiments on these:
 
 * [experiment that uses `labml.configs`](glu_variants/experiment.html)
